@@ -220,6 +220,10 @@ struct obs_source_audio {
  *
  * If a YUV format is specified, it will be automatically upsampled and
  * converted to RGB via shader on the graphics processor.
+ *
+ * NOTE: Non-YUV formats will always be treated as full range with this
+ * structure!  Use obs_source_frame2 along with obs_source_output_video2
+ * instead if partial range support is desired for non-YUV video formats.
  */
 struct obs_source_frame {
 	uint8_t             *data[MAX_AV_PLANES];
@@ -240,6 +244,21 @@ struct obs_source_frame {
 	bool                prev_frame;
 };
 
+struct obs_source_frame2 {
+	uint8_t               *data[MAX_AV_PLANES];
+	uint32_t              linesize[MAX_AV_PLANES];
+	uint32_t              width;
+	uint32_t              height;
+	uint64_t              timestamp;
+
+	enum video_format     format;
+	enum video_range_type range;
+	float                 color_matrix[16];
+	float                 color_range_min[3];
+	float                 color_range_max[3];
+	bool                  flip;
+};
+
 /** Access to the argc/argv used to start OBS. What you see is what you get. */
 struct obs_cmdline_args {
 	int argc;
@@ -794,6 +813,9 @@ EXPORT bool obs_display_enabled(obs_display_t *display);
 EXPORT void obs_display_set_background_color(obs_display_t *display,
 		uint32_t color);
 
+EXPORT void obs_display_size(obs_display_t *display,
+		uint32_t *width, uint32_t *height);
+
 
 /* ------------------------------------------------------------------------- */
 /* Sources */
@@ -995,6 +1017,18 @@ EXPORT uint32_t obs_source_get_audio_mixers(const obs_source_t *source);
  */
 EXPORT void obs_source_inc_showing(obs_source_t *source);
 
+/**
+ * Increments the 'active' reference counter to indicate that the source is
+ * fully active.  If the reference counter was 0, will call the 'activate'
+ * callback.
+ *
+ * Unlike obs_source_inc_showing, this will cause children of this source to be
+ * considered showing as well (currently used by transition previews to make
+ * the stinger transition show correctly).  obs_source_inc_showing should
+ * generally be used instead.
+ */
+EXPORT void obs_source_inc_active(obs_source_t *source);
+
 /**
  * Decrements the 'showing' reference counter to indicate that the source is
  * no longer being shown somewhere.  If the reference counter is set to 0,
@@ -1002,6 +1036,17 @@ EXPORT void obs_source_inc_showing(obs_source_t *source);
  */
 EXPORT void obs_source_dec_showing(obs_source_t *source);
 
+/**
+ * Decrements the 'active' reference counter to indicate that the source is no
+ * longer fully active.  If the reference counter is set to 0, will call the
+ * 'deactivate' callback
+ *
+ * Unlike obs_source_dec_showing, this will cause children of this source to be
+ * considered not showing as well.  obs_source_dec_showing should generally be
+ * used instead.
+ */
+EXPORT void obs_source_dec_active(obs_source_t *source);
+
 /** Enumerates filters assigned to the source */
 EXPORT void obs_source_enum_filters(obs_source_t *source,
 		obs_source_enum_proc_t callback, void *param);
@@ -1117,13 +1162,29 @@ EXPORT void obs_source_draw_set_color_matrix(
 EXPORT void obs_source_draw(gs_texture_t *image, int x, int y,
 		uint32_t cx, uint32_t cy, bool flip);
 
-/** Outputs asynchronous video data.  Set to NULL to deactivate the texture */
+/**
+ * Outputs asynchronous video data.  Set to NULL to deactivate the texture
+ *
+ * NOTE: Non-YUV formats will always be treated as full range with this
+ * function!  Use obs_source_output_video2 instead if partial range support is
+ * desired for non-YUV video formats.
+ */
 EXPORT void obs_source_output_video(obs_source_t *source,
 		const struct obs_source_frame *frame);
+EXPORT void obs_source_output_video2(obs_source_t *source,
+		const struct obs_source_frame2 *frame);
 
-/** Preloads asynchronous video data to allow instantaneous playback */
+/**
+ * Preloads asynchronous video data to allow instantaneous playback
+ *
+ * NOTE: Non-YUV formats will always be treated as full range with this
+ * function!  Use obs_source_preload_video2 instead if partial range support is
+ * desired for non-YUV video formats.
+ */
 EXPORT void obs_source_preload_video(obs_source_t *source,
 		const struct obs_source_frame *frame);
+EXPORT void obs_source_preload_video2(obs_source_t *source,
+		const struct obs_source_frame2 *frame);
 
 /** Shows any preloaded video data */
 EXPORT void obs_source_show_preloaded_video(obs_source_t *source);
@@ -1304,6 +1365,8 @@ typedef float (*obs_transition_audio_mix_callback_t)(void *data, float t);
 
 EXPORT float obs_transition_get_time(obs_source_t *transition);
 
+EXPORT void obs_transition_force_stop(obs_source_t *transition);
+
 EXPORT void obs_transition_video_render(obs_source_t *transition,
 		obs_transition_video_render_callback_t callback);
 
@@ -1453,6 +1516,8 @@ EXPORT void obs_sceneitem_get_draw_transform(const obs_sceneitem_t *item,
 		struct matrix4 *transform);
 EXPORT void obs_sceneitem_get_box_transform(const obs_sceneitem_t *item,
 		struct matrix4 *transform);
+EXPORT void obs_sceneitem_get_box_scale(const obs_sceneitem_t *item,
+		struct vec2 *scale);
 
 EXPORT bool obs_sceneitem_visible(const obs_sceneitem_t *item);
 EXPORT bool obs_sceneitem_set_visible(obs_sceneitem_t *item, bool visible);
@@ -1717,6 +1782,8 @@ EXPORT const char *obs_output_get_id(const obs_output_t *output);
 #if BUILD_CAPTIONS
 EXPORT void obs_output_output_caption_text1(obs_output_t *output,
 		const char *text);
+EXPORT void obs_output_output_caption_text2(obs_output_t *output,
+		const char *text, double display_duration);
 #endif
 
 EXPORT float obs_output_get_congestion(obs_output_t *output);
